/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/trunk/backends/platform/iphone/iphone_video.h $
 * $Id: iphone_video.h 40867 2009-05-24 15:17:42Z lordhoto $
 *
 */

#ifndef _IPHONE_VIDEO__H
#define _IPHONE_VIDEO__H

#import <engines/engine.h>
#import <engines/igob/gob.h>
#import <engines/igob/goblin.h>
#import <engines/igob/script.h>
#import <engines/igob/hotspots.h>
#import <engines/igob/game.h>

#import <vector>
#import <UIKit/UIKit.h>
#import <Foundation/Foundation.h>
#import <AVFoundation/AVFoundation.h>
#import <QuartzCore/QuartzCore.h>

#import <OpenGLES/EAGL.h>
#import <OpenGLES/ES1/gl.h>
#import <OpenGLES/ES1/glext.h>

@interface iPhoneView : UIView
{
	//VIEW PARAMS
	void* _screenSurface;
	NSMutableArray* _events;
	CALayer* _screenLayer;

	//OPENGL PARAMS
	EAGLContext* _context;
	GLuint _viewRenderbuffer;
	GLuint _viewFramebuffer;
	GLint _backingWidth;
	GLint _backingHeight;
	GLint _visibleWidth;
	GLint _visibleHeight;
	GLuint _screenTexture;
	
	//DEVICE PARAM
	UIDeviceOrientation _screenOrientation;
	
	//VIDEO PARAMS
	int _fullWidth;
	int _fullHeight;
	int _widthOffset;
	int _heightOffset;
	NSLock* _lock;

	////////////////////////////////////
	// GAME PARAMS
	//----------------------------------
	
	//OUTLETS
	IBOutlet UIButton* skipButton;
	IBOutlet UIButton* choiceButton;
	IBOutlet UIButton* hintButton;
	IBOutlet UIButton* menuButton;
	IBOutlet UIButton* rightClickButton;
	IBOutlet UIButton* gobliinButton;	
	IBOutlet UIImageView* tutoBar;
	IBOutlet UIImageView* menuBar;
	IBOutlet UIButton* openMenuBar;
	IBOutlet UIButton* closeMenuBar;	
	IBOutlet UIActivityIndicatorView* flagAct;
	
	//DISPLAY
	bool hotspotDisplayed[50];
	bool hotspotUsed[50];
	bool iconsDisplayed;
	bool alphaDisplayed[50];	
	bool bSubs;
	bool bMovementActive;
	UIImageView* hotspotImgView[50];		
	UIImage* hotspotImg;
	UIImage* invScreen;
	UIImageView* invView;
	UIAlertView* alert;
	
	//GOB
	Gob::GobEngine* gg;
	bool bMovedCursor;
	bool bActionLocked;
	bool bStepIconOn;
	bool bGob2RightClick;
	bool bGob2Flag;
	int hotspotCountLeftC;
	int hotspotCountRightC;
	int numAction;
	int xPosCur, yPosCur;
	int mEtatAction;
	float stepPosX;
	float stepPosY;
	UIImageView* cursorGobliiin;
	UIButton* _flagLabel[5];
	UILabel* _flagText[5];
	UIImageView* _flagBackground;
	bool bFlagIsComputing;
	bool bFlagCleared;
	bool bObjectsToGet;
	bool cursorFade;
	UIImageView* _warningBar;
	UILabel* _warningLabel;
	UIImageView* _warningSuperposBar;
	UILabel* _warningSuperposLabel;	
	
	//TUTO
	bool flecheWinkle;
	bool bAnimatingFleche;
	bool bAnimatingButtons;
	bool next;
	int etatTuto;
	NSTimer* timerFleche;
	UIImageView* flecheGobliin;
	UIImageView* pointerButton;
	UITextView* msgBegin;
	UITextView* headerText;
	CGRect pointerButtonRect;
	
	//MISCELLANEOUS
	NSInteger date_second;

	//SAVE
	NSString *docsDirectory;
    NSString *path;
    NSString *path_sound;
	NSString *path_control;
	NSString *path_inv;
	
	//game over screen
	UIImageView* gameoverV;
	
	//splash loading
	bool bLoadingImage;	
	IBOutlet UIImageView* loadingV;
	IBOutlet UIActivityIndicatorView * activityIndicator;

	//-----------------------------------
	/////////////////////////////////////
}

//CLASS
- (id) initWithFrame:(struct CGRect)frame;
- (void) awakeFromNib;
- (void) applicationSuspend;
- (void*) getSurface; 
- (void) updateSurface; 
- (void) initSurface;
- (id) getEvent;
- (void) addEvent:(NSDictionary*)event; 
- (void) deviceOrientationChanged:(UIDeviceOrientation)orientation; 
- (void) touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event;
- (void) touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event;
- (void) touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event;
- (void) touchesCancelled:(NSSet *)touches withEvent:(UIEvent *)event;

//ACTIONS
- (IBAction) rightButtonClicked:(id)sender;
- (IBAction) choiceButtonClicked:(id)sender;
- (void)	 gobliinButtonClicked:(id)sender;
- (void)	 openMenuBarClicked:(id)sender;
- (void)	 closeMenuBarClicked:(id)sender;

//METHODS
- (void) writeSettingsSound;
- (int)  hotspotDistance:(CGPoint)point;
- (void) hotspotDisplayCompute:(CGPoint)point;
- (void) clearButtons;
- (void) cursorCurrentGobliiin:(int)xxx coordY:(int)yyy;
- (void) showMenuBar;
- (void) hideMenuBar;
- (void) removeBoxFlag;
@end

#endif /* _IPHONE_VIDEO__H */
